Learn R Programming

era (version 0.4.1)

era_year: Year units

Description

era_year objects describe the unit used for a year as its length in days. This value is used in an era definition (era()) to enable conversions between eras that use different units (with yr_transform()).

Usage

era_year(label = character(), days = 365.2425)

Value

S3 vector of class era_year.

Arguments

label

Character. Name of the year unit.

days

Numeric. Average length of the year in solar days. Defaults to a Gregorian year (365.2425 days).

See Also

Other era helper functions: era_parameters, era_year_parameters, era, is_era_year(), is_era(), is_yr(), this_year()

Examples

Run this code
era_year("Julian", 365.25)

Run the code above in your browser using DataLab